# -*- coding: utf-8 -*-

from __future__ import unicode_literals
from __future__ import print_function

# ripped from djangotoolbox
# duplicated here to avoid external dependency


def make_tls_property(default=None):
    """Creates a class-wide instance property with a thread-specific value."""
    class TLSProperty(object):
        def __init__(self):
            from threading import local
            self.local = local()

        def __get__(self, instance, cls):
            if not instance:
                return self
            return self.value

        def __set__(self, instance, value):
            self.value = value

        def _get_value(self):
            return getattr(self.local, 'value', default)

        def _set_value(self, value):
            self.local.value = value

        value = property(_get_value, _set_value)

    return TLSProperty()



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

__name__ = 'django_agilesites'
__author__ = 'Steven Klass'
__version_info__ = (1, 0, 1)
__version__ = '.'.join(map(str, __version_info__))
__date__ = '2014/07/22 4:47:00 PM'
__credits__ = ['Steven Klass', 'Tim Valenta']
__license__ = 'See the file LICENSE.txt for licensing information.'
